@@ -46,12 +46,15 @@
 #define WINDOW_BATCH_SCAN				_("batch scan")
 #define WINDOW_BATCH_RENAME				_("rename batch area")
 #define WINDOW_FAX_PROJECT				_("fax project")
+#define WINDOW_FAX_PROJECT_BROWSE			_("browse for fax project")
 #define WINDOW_FAX_RENAME				_("rename fax page")
 #define WINDOW_FAX_INSERT				_("insert ps-file into fax")
 #define WINDOW_EMAIL_PROJECT				_("E-mail project")
+#define WINDOW_EMAIL_PROJECT_BROWSE			_("browse for email project")
 #define WINDOW_EMAIL_RENAME				_("rename e-mail image")
 #define WINDOW_EMAIL_INSERT				_("insert file into e-mail")
 #define WINDOW_MULTIPAGE_PROJECT			_("multipage project")
+#define WINDOW_MULTIPAGE_PROJECT_BROWSE			_("browse for multipage project")
 #define WINDOW_PRESET_AREA_RENAME			_("rename preset area")
 #define WINDOW_PRESET_AREA_ADD				_("add preset area")
 #define WINDOW_MEDIUM_RENAME				_("rename medium")
@@ -76,10 +79,11 @@
 #define WINDOW_BLUR					_("Blur image")
 #define WINDOW_STORE_MEDIUM				_("Store medium definition")
 #define WINDOW_NO_DEVICES				_("No devices available")
-#define WINDOW_SCANNER_REFL_ICM_PROFILE			_("select scanner reflective ICM-profile")
-#define WINDOW_SCANNER_TRAN_ICM_PROFILE			_("select scanner transmissive ICM-profile")
+#define WINDOW_SCANNER_DEFAULT_COLOR_ICM_PROFILE	_("select scanner default color ICM-profile")
+#define WINDOW_SCANNER_DEFAULT_GRAY_ICM_PROFILE		_("select scanner default gray ICM-profile")
 #define WINDOW_DISPLAY_ICM_PROFILE			_("select display ICM-profile")
 #define WINDOW_CUSTOM_PROOFING_ICM_PROFILE		_("select custom proofing ICM-profile")
+#define WINDOW_WORKING_COLOR_SPACE_ICM_PROFILE		_("select working color space ICM-profile")
 #define WINDOW_PRINTER_ICM_PROFILE			_("select printer ICM-profile")
 
 #define MENU_FILE					_("File")
@@ -157,23 +161,24 @@
 #define RADIO_BUTTON_SAVE_DEVPREFS_AT_EXIT		_("Save device preferences at exit")
 #define RADIO_BUTTON_OVERWRITE_WARNING			_("Overwrite warning")
 #define RADIO_BUTTON_SKIP_EXISTING_NRS			_("Skip existing filenames")
-#define RADIO_BUTTON_SAVE_PS_FLATDECODED		_("Save postscript zlib compressed (ps level 3)")
-#define RADIO_BUTTON_SAVE_PDF_FLATDECODED		_("Save PDF zlib compressed")
+#define RADIO_BUTTON_SAVE_PS_FLATEDECODED		_("Save postscript zlib compressed (ps level 3)")
+#define RADIO_BUTTON_SAVE_PDF_FLATEDECODED		_("Save PDF zlib compressed")
 #define RADIO_BUTTON_SAVE_PNM16_AS_ASCII		_("Save 16bit pnm in ascii format")
 #define RADIO_BUTTON_REDUCE_16BIT_TO_8BIT		_("Reduce 16 bit image to 8 bit")
 #define RADIO_BUTTON_WINDOW_FIXED			_("Main window size fixed")
-#define RADIO_BUTTON_DISABLE_GIMP_PREVIEW_GAMMA		_("Disable gimp preview gamma")
+#define RADIO_BUTTON_DISABLE_GIMP_PREVIEW_GAMMA		_("Disable GIMP preview gamma")
 #define RADIO_BUTTON_PRIVATE_COLORMAP			_("Use private colormap")
 #define RADIO_BUTTON_AUTOENHANCE_GAMMA  		_("Autoenhance gamma")
 #define RADIO_BUTTON_PRESELECT_SCANAREA 		_("Preselect scanarea")
 #define RADIO_BUTTON_AUTOCORRECT_COLORS 		_("Autocorrect colors")
 #define RADIO_BUTTON_OCR_USE_GUI_PIPE			_("Use GUI progress pipe")
-#define RADIO_BUTTON_EMBED_ICM_PROFILE			_("Embed scanner/source ICM profile into image file")
+#define RADIO_BUTTON_CMS_BPC				_("Black point compensation")
 
 #define TEXT_SCANNING_DEVICES				_("scanning for devices")
 #define TEXT_AVAILABLE_DEVICES				_("Available devices:")
 #define TEXT_XSANE_OPTIONS				_("XSane options")
 #define TEXT_FILETYPE					_("Type")
+#define TEXT_CMS_FUNCTION				_("Color management function")
 #define TEXT_SCANNER_BACKEND				_("Scanner and backend:")
 #define TEXT_VENDOR					_("Vendor:")
 #define TEXT_MODEL					_("Model:")
@@ -192,10 +197,8 @@
 #define TEXT_OUTPUT_FORMATS				_("XSane output formats:")
 #define TEXT_8BIT_FORMATS				_("8 bit output formats:")
 #define TEXT_16BIT_FORMATS				_("16 bit output formats:")
-#define TEXT_GIMP_REDUCE_16BIT_TO_8BIT			_("Gimp does not support depth 16 bits/color.\n" \
-                                        		  "Do you want to reduce the depth to 8 bits/color?")
-#define TEXT_REDUCE_16BIT_TO_8BIT			_("Bit depth 16 bits/color is not supported for this output format.\n" \
-                                        		  "Do you want to reduce the depth to 8 bits/color?")
+#define TEXT_REDUCE_16BIT_TO_8BIT			_("Bit depth 16 bits/channel is not supported for this output format.\n" \
+                                        		  "Do you want to reduce the depth to 8 bits/channel?")
 #define TEXT_AUTHORIZATION_REQ				_("Authorization required for")
 #define TEXT_AUTHORIZATION_SECURE			_("Password transmission is secure")
 #define TEXT_AUTHORIZATION_INSECURE			_("Backend requests plain-text password")
@@ -255,7 +258,7 @@
 
 #define TEXT_MEDIUM_DEFINITION_NAME			_("Medium Name:")
 
-#define TEXT_VIEWER_IMAGE_INFO				_("Size %d x %d pixel, %d bit/color, %d colors, %1.0f dpi x %1.0f dpi, %1.1f %s")
+#define TEXT_VIEWER_IMAGE_INFO				_("Size %d x %d pixel, %d bits/channel, %d channels, %1.0f dpi x %1.0f dpi, %1.1f %s")
 #define TEXT_DESPECKLE_RADIUS				_("Despeckle radius:")
 #define TEXT_BLUR_RADIUS				_("Blur radius:")
 #define TEXT_BATCH_AREA_DEFAULT_NAME			_("(no name)")
@@ -282,7 +285,10 @@
 #define TEXT_SETUP_PRINTER_GAMMA_RED			_("Printer gamma red:")
 #define TEXT_SETUP_PRINTER_GAMMA_GREEN			_("Printer gamma green:")
 #define TEXT_SETUP_PRINTER_GAMMA_BLUE			_("Printer gamma blue:")
-#define TEXT_SETUP_PRINTER_PS_FLATDECODED		_("Create zlib compressed postscript image (ps level 3) for printing")
+#define TEXT_SETUP_PRINTER_EMBED_CSA			_("Embed scanner ICM profile as CSA")
+#define TEXT_SETUP_PRINTER_EMBED_CRD			_("Embed printer ICM profile as CRD")
+#define TEXT_SETUP_PRINTER_CMS_BPC			_("Apply black point compensation")
+#define TEXT_SETUP_PRINTER_PS_FLATEDECODED		_("Create zlib compressed postscript image (ps level 3) for printing")
 #define TEXT_SETUP_TMP_PATH				_("Temporary directory")
 #define TEXT_SETUP_IMAGE_PERMISSION			_("Image-file permissions")
 #define TEXT_SETUP_DIR_PERMISSION			_("Directory permissions")
@@ -318,7 +324,7 @@
 #define TEXT_SETUP_FAX_HEIGHT				_("Height")
 #define TEXT_SETUP_FAX_LEFT				_("Left offset")
 #define TEXT_SETUP_FAX_BOTTOM				_("Bottom offset")
-#define TEXT_SETUP_FAX_PS_FLATDECODED			_("Create zlib compressed postscript image (ps level 3) for fax")
+#define TEXT_SETUP_FAX_PS_FLATEDECODED			_("Create zlib compressed postscript image (ps level 3) for fax")
 #define TEXT_SETUP_SMTP_SERVER				_("SMTP server:")
 #define TEXT_SETUP_SMTP_PORT				_("SMTP port:")
 #define TEXT_SETUP_EMAIL_FROM				_("From:")
@@ -337,10 +343,11 @@
 #define TEXT_SETUP_PERMISSION_USER			_("user")
 #define TEXT_SETUP_PERMISSION_GROUP			_("group")
 #define TEXT_SETUP_PERMISSION_ALL			_("all")
-#define TEXT_SETUP_SCANNER_REFL_ICM_PROFILE		_("Scanner reflective ICM-profile")
-#define TEXT_SETUP_SCANNER_TRAN_ICM_PROFILE		_("Scanner transmissive ICM-profile")
+#define TEXT_SETUP_SCANNER_DEFAULT_COLOR_ICM_PROFILE	_("Scanner default color ICM-profile")
+#define TEXT_SETUP_SCANNER_DEFAULT_GRAY_ICM_PROFILE	_("Scanner default gray ICM-profile")
 #define TEXT_SETUP_DISPLAY_ICM_PROFILE			_("Display ICM-profile")
 #define TEXT_SETUP_CUSTOM_PROOFING_ICM_PROFILE		_("Custom proofing ICM-profile")
+#define TEXT_SETUP_WORKING_COLOR_SPACE_ICM_PROFILE	_("Working color space ICM-profile")
 #define TEXT_SETUP_PRINTER_ICM_PROFILE			_("Printer ICM-profile")
 #define	TEXT_NEW_MEDIA_NAME				_("new media")
 
@@ -452,6 +459,10 @@
 #define MENU_ITEM_AUTH_ASMTP_LOGIN	_("ASMTP Login")
 #define MENU_ITEM_AUTH_ASMTP_CRAM_MD5	_("ASMTP CRAM-MD5")
 
+#define MENU_ITEM_CMS_FUNCTION_EMBED_SCANNER_ICM_PROFILE	_("Embed scanner ICM profile")
+#define MENU_ITEM_CMS_FUNCTION_CONVERT_TO_SRGB			_("Convert to sRGB")
+#define MENU_ITEM_FUNCTION_CONVERT_TO_WORKING_CS		_("Convert to working color space")
+
 #define PROGRESS_SCANNING		_("Scanning")
 #define PROGRESS_RECEIVING_FRAME_DATA	_("Receiving %s data")
 #define PROGRESS_PAGE			_("page")
@@ -467,6 +478,7 @@
 #define PROGRESS_DESPECKLING_DATA	_("Despeckling image")
 #define PROGRESS_BLURING_DATA		_("Bluring image")
 #define PROGRESS_OCR			_("OCR in progress")
+#define PROGRESS_ICM_CONVERSION		_("converting colors")
 
 #define DESC_SCAN_START			_("Start scan <Ctrl-Enter>")
 #define DESC_SCAN_CANCEL		_("Cancel scan <ESC>")
@@ -482,15 +494,18 @@
 #define DESC_BROWSE_FILENAME		_("Browse for image filename")
 #define DESC_FILENAME			_("Filename for scanned image")
 #define DESC_FILETYPE			_("Type of image format, the suitable filename extension is automatically added to the filename")
-#define DESC_FAXPROJECT			_("Enter name of fax project")
+#define DESC_FAXPROJECT			_("Enter fax project directory name")
 #define DESC_FAXPAGENAME		_("Enter new name for faxpage")
 #define DESC_FAXRECEIVER		_("Enter receiver phone number or address")
-#define DESC_EMAIL_PROJECT		_("Enter name of e-mail project")
+#define DESC_FAX_PROJECT_BROWSE		_("Browse for fax project directory")
+#define DESC_EMAIL_PROJECT		_("Enter e-mail project directory name")
 #define DESC_EMAIL_IMAGENAME		_("Enter new name for e-mail image")
 #define DESC_EMAIL_RECEIVER		_("Enter e-mail address")
+#define DESC_EMAIL_PROJECT_BROWSE	_("Browse for email project directory")
 #define DESC_EMAIL_SUBJECT		_("Enter subject of e-mail")
 #define DESC_EMAIL_FILETYPE		_("Select filetype for image attachments")
-#define DESC_MULTIPAGE_PROJECT		_("Enter name of multipage project")
+#define DESC_MULTIPAGE_PROJECT		_("Enter multipage project directory name")
+#define DESC_MULTIPAGE_PROJECT_BROWSE	_("Browse for multipage project directory")
 #define DESC_MULTIPAGE_FILETYPE		_("Select filetype for multipage file")
 #define DESC_PRESET_AREA_RENAME		_("Enter new name for preset area")
 #define DESC_PRESET_AREA_ADD		_("Enter name for new preset area")
@@ -562,7 +577,10 @@
 #define DESC_PRINTER_GAMMA_RED		_("Additional gamma value for red component for photocopy")
 #define DESC_PRINTER_GAMMA_GREEN	_("Additional gamma value for green component for photocopy")
 #define DESC_PRINTER_GAMMA_BLUE		_("Additional gamma value for blue component for photocopy")
-#define DESC_PRINTER_PS_FLATDECODED	_("Create zlib compressed postscript image for printer (flatdecode).\n" \
+#define DESC_PRINTER_EMBED_CSA		_("Creates a postsciptfile that contains the ICM profile of the scanner")
+#define DESC_PRINTER_EMBED_CRD		_("Creates a postsciptfile that contains the ICM profile of the printer")
+#define DESC_PRINTER_CMS_BPC		_("Applies black point compensation")
+#define DESC_PRINTER_PS_FLATEDECODED	_("Create zlib compressed postscript image for printer (flatedecode).\n" \
                                           "The printer has to understand postscript level 3!")
 #define DESC_TMP_PATH			_("Path to temp directory")
 #define DESC_BUTTON_TMP_PATH_BROWSE	_("Browse for temporary directory")
@@ -576,20 +594,20 @@
 #define DESC_SAVE_DEVPREFS_AT_EXIT	_("Save device dependant preferences in default file at exit of xsane")
 #define DESC_OVERWRITE_WARNING		_("Warn before overwriting an existing file")
 #define DESC_SKIP_EXISTING		_("If filename counter is automatically increased, used numbers are skipped")
-#define DESC_SAVE_PS_FLATDECODED	_("compress postscript image with zlib algorithm (flatdecode). " \
+#define DESC_SAVE_PS_FLATEDECODED	_("compress postscript image with zlib algorithm (flatedecode). " \
                                           "When you want to print such a file your printer has to understand postscript level 3")
-#define DESC_SAVE_PDF_FLATDECODED	_("compress PDF image with zlib algorithm (flatdecode).")
+#define DESC_SAVE_PDF_FLATEDECODED	_("compress PDF image with zlib algorithm (flatedecode).")
 #define DESC_SAVE_PNM16_AS_ASCII	_("When a 16 bit image shall be saved in pnm format then use ascii format " \
                                           "instead of binary format. The binary format is a new format that is not " \
                                           "supported by all programs. The ascii format is supported by more programs " \
                                           "but it produces really huge files!!!")
-#define DESC_REDUCE_16BIT_TO_8BIT	_("If scanner sends image with 16 bits/color save image with 8 bits/color")
+#define DESC_REDUCE_16BIT_TO_8BIT	_("If scanner sends image with 16 bits/channel save image with 8 bits/channel")
 #define DESC_PSFILE_WIDTH		_("Width of paper for postscript files")
 #define DESC_PSFILE_HEIGHT		_("Height of paper for postscript files")
 #define DESC_PSFILE_LEFTOFFSET		_("Left offset from the edge of the paper to the usable area for postscript files")
 #define DESC_PSFILE_BOTTOMOFFSET	_("Bottom offset from the edge of the paper to the usable area for postscript files")
 #define DESC_MAIN_WINDOW_FIXED		_("Use fixed main window size or scrolled, resizable main window")
-#define DESC_DISABLE_GIMP_PREVIEW_GAMMA	_("Disable preview gamma when XSane runs as gimp plugin")
+#define DESC_DISABLE_GIMP_PREVIEW_GAMMA	_("Disable preview gamma when XSane runs as GIMP plugin")
 #define DESC_PREVIEW_COLORMAP		_("Use an own colormap for preview if display depth is 8 bpp")
 #define DESC_SHOW_RANGE_MODE		_("Select how a range is displayed")
 #define DESC_PREVIEW_OVERSAMPLING	_("Value with that the calculated preview resolution is multiplied")
@@ -612,7 +630,8 @@
 #define DESC_PRESELECT_SCANAREA		_("Select scanarea after preview scan has finished")
 #define DESC_AUTOCORRECT_COLORS		_("Do color correction after preview scan has finished")
 
-#define DESC_EMBED_ICM_PROFILE		_("Embed scanner/source ICM profile into image file - when fileformat supports it")
+#define DESC_RENDERING_INTENT		_("Select rendering intent for preview and saving")
+#define DESC_CMS_BPC			_("Apply black point compensation when color transformation is done")
 
 #define DESC_FAX_COMMAND		_("Enter command to be executed in fax mode")
 #define DESC_FAX_RECEIVER_OPT		_("Enter option to specify receiver")
@@ -625,7 +644,7 @@
 #define DESC_FAX_HEIGHT			_("Height of printable area")
 #define DESC_FAX_LEFTOFFSET		_("Left offset from the edge of the paper to the printable area")
 #define DESC_FAX_BOTTOMOFFSET		_("Bottom offset from the edge of the paper to the printable area")
-#define DESC_FAX_PS_FLATDECODED		_("Create zlib compressed postscript image for fax (flatdecode)")
+#define DESC_FAX_PS_FLATEDECODED	_("Create zlib compressed postscript image for fax (flatedecode)")
 #define DESC_SMTP_SERVER		_("IP Address or Domain name of SMTP server")
 #define DESC_SMTP_PORT			_("port to connect to SMTP server")
 #define DESC_EMAIL_FROM			_("enter your e-mail address")
@@ -697,16 +716,20 @@
 #define DESC_BATCH_DEL			_("Delete selected area from batch list")
 #define DESC_AUTOMATIC			_("Turns on automatic mode")
 
-#define DESC_SCANNER_REFL_ICM_PROFILE			_("Scanner reflektive ICM-profile")
-#define DESC_BUTTON_SCANNER_REFL_ICM_PROFILE_BROWSE	_("Browse for scanner reflektive ICM-profile")
-#define DESC_SCANNER_TRAN_ICM_PROFILE			_("Scanner transmissive ICM-profile")
-#define DESC_BUTTON_SCANNER_TRAN_ICM_PROFILE_BROWSE	_("Browse for scanner transmissive ICM-profile")
+#define DESC_SCANNER_DEFAULT_COLOR_ICM_PROFILE			_("Scanner default color ICM-profile")
+#define DESC_BUTTON_SCANNER_DEFAULT_COLOR_ICM_PROFILE_BROWSE	_("Browse for scanner default color ICM-profile")
+#define DESC_SCANNER_DEFAULT_GRAY_ICM_PROFILE			_("Scanner default gray ICM-profile")
+#define DESC_BUTTON_SCANNER_DEFAULT_GRAY_ICM_PROFILE_BROWSE	_("Browse for scanner default gray ICM-profile")
 #define DESC_DISPLAY_ICM_PROFILE			_("Display ICM-profile")
 #define DESC_BUTTON_DISPLAY_ICM_PROFILE_BROWSE		_("Browse for display ICM-profile")
 #define DESC_PRINTER_ICM_PROFILE			_("Printer ICM-profile")
 #define DESC_BUTTON_PRINTER_ICM_PROFILE_BROWSE		_("Browse for printer ICM-profile")
 #define DESC_CUSTOM_PROOFING_ICM_PROFILE		_("Custom proofing ICM-profile")
 #define DESC_BUTTON_CUSTOM_PROOFING_ICM_PROFILE_BROWSE	_("Browse for custom proofing ICM-profile")
+#define DESC_WORKING_COLOR_SPACE_ICM_PROFILE		_("Working color space ICM-profile")
+#define DESC_BUTTON_WORKING_COLOR_SPACE_ICM_PROFILE_BROWSE	_("Browse for working color space ICM-profile")
+
+#define DESC_CMS_FUNCTION		_("Color management function")
 
 #define ERR_HOME_DIR			_("Failed to determine home directory:")
 #define ERR_CHANGE_WORKING_DIR		_("Failed to change working directory to")
@@ -723,7 +746,6 @@ write permissions." )
 #define ERR_DURING_READ			_("Error during read:")
 #define ERR_DURING_SAVE			_("Error during save:")
 #define ERR_BAD_DEPTH			_("Can't handle depth")
-#define ERR_GIMP_BAD_DEPTH		_("GIMP can't handle depth %d bits/color")
 #define ERR_UNKNOWN_SAVING_FORMAT	_("Unknown file format for saving")
 #define ERR_OPEN_FAILED			_("Failed to open")
 #define ERR_CREATE_SECURE_FILE		_("Could not create secure file (may be a link does exist):")
@@ -793,14 +815,20 @@ YOU ARE ALONE!\
 
 #define ERR_CMS_CONVERSION		_("Error during CMS conversion:")
 #define ERR_CMS_OPEN_ICM_FILE		_("Could not open")
-#define CMS_SCANNER_TRAN_ICM		_("scanner transmissive ICM profile")
-#define CMS_SCANNER_REFL_ICM		_("scanner reflective ICM profile")
+#define CMS_SCANNER_ICM			_("scanner ICM profile")
 #define CMS_DISPLAY_ICM			_("display ICM profile")
 #define CMS_PROOF_ICM			_("proofing ICM profile")
 #define ERR_CMS_CREATE_TRANSFORM	_("Could not create transform")
 
 #define WARN_VIEWER_IMAGE_NOT_SAVED	_("viewer image is not saved")
 
+#define FILE_FILTER_ALL_FILES			_("All files")
+#define FILE_FILTER_IMAGES			_("Images")
+#define FILE_FILTER_XBL				_("XSane batch list")
+#define FILE_FILTER_ICM				_("ICC/ICM Profiles")
+#define FILE_FILTER_DRC				_("XSane device preferences")
+#define FILE_FILTER_RC				_("XSane preferences")
+
 #define TEXT_USAGE			_("Usage:")
 #define TEXT_USAGE_OPTIONS		_("[OPTION]... [DEVICE]")
 #define TEXT_HELP			_(\
@@ -907,4 +935,5 @@ The format of [DEVICE] is backendname:devicefile (e.g. umax:/dev/scanner).\n\
 
 #define TEXT_FAX_STATUS_QUEUEING_FAX		N_("Queueing Fax")
 #define TEXT_FAX_STATUS_FAX_QUEUED		N_("Fax is queued")
+
 #endif
